summaryrefslogtreecommitdiff
path: root/ace/Reverse_Lock_T.h
diff options
context:
space:
mode:
authorOssama Othman <ossama-othman@users.noreply.github.com>2005-10-28 16:14:56 +0000
committerOssama Othman <ossama-othman@users.noreply.github.com>2005-10-28 16:14:56 +0000
commit2aa4f50f829476ae276ba391127cc7266f603c96 (patch)
treec4fe2b70acf02ce19d199713fff6dec5645d8a93 /ace/Reverse_Lock_T.h
parent28934d0116426fa37e2a562cfa0d95fa34241051 (diff)
downloadATCD-2aa4f50f829476ae276ba391127cc7266f603c96.tar.gz
ChangeLogTag:Fri Oct 28 00:01:06 2005 Ossama Othman <ossama@dre.vanderbilt.edu>
Diffstat (limited to 'ace/Reverse_Lock_T.h')
-rw-r--r--ace/Reverse_Lock_T.h13
1 files changed, 9 insertions, 4 deletions
diff --git a/ace/Reverse_Lock_T.h b/ace/Reverse_Lock_T.h
index 29f23b08c08..6bb06ae244e 100644
--- a/ace/Reverse_Lock_T.h
+++ b/ace/Reverse_Lock_T.h
@@ -22,10 +22,13 @@
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */
+
+ACE_BEGIN_VERSIONED_NAMESPACE_DECL
+
/**
- * @class ACE_Acquire_Method
+ * @namespace ACE_Acquire_Method
*
* @brief An enum class.
*
* These enums should have been inside the reverse lock class, but
* some lame compilers cannot handle enums inside template classes.
@@ -38,7 +41,7 @@
* represented here because we have to make sure that the release()
* method on the reverse lock acquires a lock on the real lock.
**/
-class ACE_Acquire_Method
+namespace ACE_Acquire_Method
{
public:
enum METHOD_TYPE
@@ -47,7 +50,7 @@ public:
ACE_READ,
ACE_WRITE
};
-};
+}
/**
* @class ACE_Reverse_Lock
@@ -120,6 +123,8 @@ private:
ACE_Acquire_Method::METHOD_TYPE acquire_method_;
};
+ACE_END_VERSIONED_NAMESPACE_DECL
+
#if defined (__ACE_INLINE__)
#include "ace/Reverse_Lock_T.inl"
#endif /* __ACE_INLINE__ */
@@ -22,10 +22,13 @@
*
- * @brief An enum class.
+ * @brief An enum namespace.
*
* These enums should have been inside the reverse lock class, but